#========================================================================================
# package      t::PatchInstallHandler
# base         DE_EPAGES::Core::API::Test
# state        public
#----------------------------------------------------------------------------------------
# description  Test class for the Patch API module API::PatchInstallHandler.
#========================================================================================
package t::PatchInstallHandler;
use base DE_EPAGES::Core::API::Test;

use API::Patch::PatchInstallHandler;
use DE_EPAGES::Database::API::Config qw( DatabaseConfig );

use Test::Exception;
use Test::More;

use strict;

my @TEST_STORES = ('Site', 'Store');

## no critic qw(Subroutines::ProtectPrivateSubs)

sub test {
    my $self = shift;
    $self->test_SetPatchRunning();
    done_testing();
}


sub test_SetPatchRunning {
    my $self = shift;

    for my $Store (@TEST_STORES) {
        API::Patch::PatchInstallHandler::_SetPatchRunning(\@TEST_STORES, 1);

        my $IniConfig = DatabaseConfig($Store);
        my $IsPatchRunning = $IniConfig->get('Patch', 'IsPatchRunning');
        cmp_ok($IsPatchRunning, '==', 1, "PatchRunning state for store '$Store' is set to true.");
    }

    for my $Store (@TEST_STORES) {
        API::Patch::PatchInstallHandler::_SetPatchRunning(\@TEST_STORES, 0);

        my $IniConfig = DatabaseConfig($Store);
        my $IsPatchRunning = $IniConfig->get('Patch', 'IsPatchRunning');
        cmp_ok($IsPatchRunning, '==', 0, "PatchRunning state for store '$Store' is set to false.");
    }
}

sub cleanup {
    for my $Store (@TEST_STORES) {
        my $IniConfig = DatabaseConfig($Store);
        $IniConfig->set( 'Patch', 'IsPatchRunning', 0 );
        $IniConfig->rewrite();
    }
}


__PACKAGE__->runScript();

1;